@@ -1,3 +1,5 @@
+# -*- Mode: Python -*-
+# vi:si:et:sw=4:sts=4:ts=4
 #
 # gst-python
 # Copyright (C) 2002 David I. Lehn
@@ -18,10 +20,6 @@
 # Boston, MA 02111-1307, USA.
 # 
 # Author: David I. Lehn <dlehn@users.sourceforge.net>
-#
-
-import sys
-import dl
 
 try:
    import ltihooks
@@ -31,7 +29,11 @@ except:
 import gobject
 del gobject
 
-sys.setdlopenflags(dl.RTLD_LAZY | dl.RTLD_GLOBAL)
-del sys, dl
+try:
+   import sys, DLFCN
+   sys.setdlopenflags(DLFCN.RTLD_LAZY | DLFCN.RTLD_GLOBAL)
+   del sys, DLFCN
+except ImportError:
+   pass
 
 from _gst import *
