@@ -7,6 +7,10 @@ import pygtk
 pygtk.require('2.0')
 
 import gobject
+try:
+    gobject.threads_init()
+except:
+    print "WARNING: gobject doesn't have threads_init, no threadsafety"
 
 # Don't insert before .
 sys.path.insert(1, os.path.join('..'))
@@ -32,6 +36,14 @@ try:
 except ImportError:
    pass
 
+# testhelper needs ltihooks
+import gst.ltihooks
+
+import testhelper
+
+# finally remove ltihooks
+gst.ltihooks.uninstall()
+
 _stderr = None
 
 def disable_stderr():
